[nautilus-actions/file-manager-actions] nact_menu_xxx are renamed to fma_menu_xxx



commit f632b29b73b87bfd65be1dd15c321a7a1f1ecdda
Author: Pierre Wieser <pwieser trychlos org>
Date:   Tue Sep 8 20:22:24 2015 +0200

    nact_menu_xxx are renamed to fma_menu_xxx

 src/ui/Makefile.am                                 |   40 ++++----
 src/ui/fma-application.c                           |    4 +-
 src/ui/fma-confirm-logout.c                        |    4 +-
 src/ui/fma-main-window-def.h                       |    4 +-
 src/ui/fma-main-window.c                           |    4 +-
 src/ui/{nact-menu-edit.c => fma-menu-edit.c}       |   74 +++++++-------
 src/ui/{nact-menu-edit.h => fma-menu-edit.h}       |   20 ++--
 src/ui/{nact-menu-file.c => fma-menu-file.c}       |   62 ++++++------
 src/ui/{nact-menu-file.h => fma-menu-file.h}       |   18 ++--
 src/ui/{nact-menu-view.c => fma-menu-view.c}       |   36 ++++----
 src/ui/{nact-menu-view.h => fma-menu-view.h}       |   16 ++--
 src/ui/{nact-menu.c => fma-menu.c}                 |  104 ++++++++++----------
 src/ui/{nact-menu.h => fma-menu.h}                 |   70 +++++++-------
 ...-actions-config-tool.actions => fma-ui.actions} |    0
 14 files changed, 228 insertions(+), 228 deletions(-)
---
diff --git a/src/ui/Makefile.am b/src/ui/Makefile.am
index b0bb214..e4fe143 100644
--- a/src/ui/Makefile.am
+++ b/src/ui/Makefile.am
@@ -69,18 +69,18 @@ fma_config_tool_SOURCES = \
        egg-tree-multi-dnd.c                                                            \
        egg-tree-multi-dnd.h                                                            \
        main.c                                                                                          \
-       fma-add-capability-dialog.c                                             \
-       fma-add-capability-dialog.h                                             \
-       fma-add-scheme-dialog.c                                                 \
-       fma-add-scheme-dialog.h                                                 \
+       fma-add-capability-dialog.c                                                     \
+       fma-add-capability-dialog.h                                                     \
+       fma-add-scheme-dialog.c                                                         \
+       fma-add-scheme-dialog.h                                                         \
        fma-application.c                                                                       \
        fma-application.h                                                                       \
        fma-assistant-export.c                                                          \
        fma-assistant-export.h                                                          \
        fma-assistant-import.c                                                          \
        fma-assistant-import.h                                                          \
-       fma-clipboard.c                                                                 \
-       fma-clipboard.h                                                                 \
+       fma-clipboard.c                                                                         \
+       fma-clipboard.h                                                                         \
        fma-confirm-logout.c                                                            \
        fma-confirm-logout.h                                                            \
        fma-export-ask.c                                                                        \
@@ -89,8 +89,8 @@ fma_config_tool_SOURCES = \
        fma-iaction-tab.h                                                                       \
        fma-ibasenames-tab.c                                                            \
        fma-ibasenames-tab.h                                                            \
-       fma-icapabilities-tab.c                                                 \
-       fma-icapabilities-tab.h                                                 \
+       fma-icapabilities-tab.c                                                         \
+       fma-icapabilities-tab.h                                                         \
        fma-icommand-tab.c                                                                      \
        fma-icommand-tab.h                                                                      \
        fma-icon-chooser.c                                                                      \
@@ -114,14 +114,14 @@ fma_config_tool_SOURCES = \
        fma-main-window-def.h                                                           \
        fma-match-list.c                                                                        \
        fma-match-list.h                                                                        \
-       nact-menu.c                                                                                     \
-       nact-menu.h                                                                                     \
-       nact-menu-edit.c                                                                        \
-       nact-menu-edit.h                                                                        \
-       nact-menu-file.c                                                                        \
-       nact-menu-file.h                                                                        \
-       nact-menu-view.c                                                                        \
-       nact-menu-view.h                                                                        \
+       fma-menu.c                                                                                      \
+       fma-menu.h                                                                                      \
+       fma-menu-edit.c                                                                         \
+       fma-menu-edit.h                                                                         \
+       fma-menu-file.c                                                                         \
+       fma-menu-file.h                                                                         \
+       fma-menu-view.c                                                                         \
+       fma-menu-view.h                                                                         \
        nact-preferences-editor.c                                                       \
        nact-preferences-editor.h                                                       \
        nact-providers-list.c                                                           \
@@ -149,17 +149,17 @@ fma_config_tool_LDADD = \
        $(NULL)
 
 actions_files = \
-       nautilus-actions-config-tool.actions                            \
+       fma-ui.actions                                                                          \
        $(NULL)
 
 ui_files = \
        fma-add-capability.ui                                                           \
        fma-add-scheme.ui                                                                       \
-       fma-assistant-export.ui                                                 \
-       fma-assistant-import.ui                                                 \
+       fma-assistant-export.ui                                                         \
+       fma-assistant-import.ui                                                         \
        fma-confirm-logout.ui                                                           \
        fma-export-ask.ui                                                                       \
-       fma-icon-chooser.ui                                                             \
+       fma-icon-chooser.ui                                                                     \
        nact-legend.ui                                                                          \
        fma-main-window.ui                                                                      \
        nact-preferences.ui                                                                     \
diff --git a/src/ui/fma-application.c b/src/ui/fma-application.c
index 9005a39..e092de2 100644
--- a/src/ui/fma-application.c
+++ b/src/ui/fma-application.c
@@ -41,7 +41,7 @@
 #include "base-isession.h"
 #include "fma-application.h"
 #include "fma-main-window.h"
-#include "nact-menu.h"
+#include "fma-menu.h"
 
 /* private instance data
  */
@@ -424,7 +424,7 @@ application_startup( GApplication *application )
        fma_pivot_set_loadable( FMA_PIVOT( priv->updater ), PIVOT_LOAD_ALL );
 
        /* define the application menu */
-       nact_menu_app( FMA_APPLICATION( application ));
+       fma_menu_app( FMA_APPLICATION( application ));
 }
 
 /*
diff --git a/src/ui/fma-confirm-logout.c b/src/ui/fma-confirm-logout.c
index 29350ff..68116b8 100644
--- a/src/ui/fma-confirm-logout.c
+++ b/src/ui/fma-confirm-logout.c
@@ -35,7 +35,7 @@
 
 #include "fma-confirm-logout.h"
 #include "fma-main-window-def.h"
-#include "nact-menu-file.h"
+#include "fma-menu-file.h"
 
 /* private instance data
  */
@@ -298,7 +298,7 @@ on_save_and_quit_clicked( GtkButton *button, FMAConfirmLogout *editor )
        g_debug( "%s: button=%p, editor=%p", thisfn, ( void * ) button, ( void * ) editor );
 
        main_window = FMA_MAIN_WINDOW( base_window_get_main_window( BASE_WINDOW( editor )));
-       nact_menu_file_save_items( main_window );
+       fma_menu_file_save_items( main_window );
 
        close_dialog( editor, TRUE );
 }
diff --git a/src/ui/fma-main-window-def.h b/src/ui/fma-main-window-def.h
index bd980ec..aecadfc 100644
--- a/src/ui/fma-main-window-def.h
+++ b/src/ui/fma-main-window-def.h
@@ -57,7 +57,7 @@
  *  |    on_startup()
  *  |      |
  *  |      +-> fma_updater_new()
- *  |          nact_menu_app()
+ *  |          fma_menu_app()
  *  |
  *  |    on_activate()
  *  |      |
@@ -81,7 +81,7 @@
  *  |
  *  |               setup_monitor_pivot()
  *  |               setup_delete_event()
- *  |               nact_menu_win()
+ *  |               fma_menu_win()
  *  |               load_items()
  *  v
  * [X] End of initialization process
diff --git a/src/ui/fma-main-window.c b/src/ui/fma-main-window.c
index 1d6c26f..efcf1d1 100644
--- a/src/ui/fma-main-window.c
+++ b/src/ui/fma-main-window.c
@@ -54,7 +54,7 @@
 #include "fma-iproperties-tab.h"
 #include "fma-main-tab.h"
 #include "fma-main-window.h"
-#include "nact-menu.h"
+#include "fma-menu.h"
 #include "nact-statusbar.h"
 #include "nact-tree-view.h"
 #include "fma-confirm-logout.h"
@@ -663,7 +663,7 @@ fma_main_window_new( FMAApplication *application )
 
        setup_main_ui( window );
        setup_treeview( window );
-       nact_menu_win( window );
+       fma_menu_win( window );
 
        window->private->clipboard = fma_clipboard_new( window );
        window->private->sort_buttons = nact_sort_buttons_new( window );
diff --git a/src/ui/nact-menu-edit.c b/src/ui/fma-menu-edit.c
similarity index 90%
rename from src/ui/nact-menu-edit.c
rename to src/ui/fma-menu-edit.c
index cc88c3f..1b2c9b5 100644
--- a/src/ui/nact-menu-edit.c
+++ b/src/ui/fma-menu-edit.c
@@ -41,8 +41,8 @@
 #include "fma-clipboard.h"
 #include "fma-main-tab.h"
 #include "fma-main-window.h"
-#include "nact-menu.h"
-#include "nact-menu-edit.h"
+#include "fma-menu.h"
+#include "fma-menu-edit.h"
 #include "nact-tree-ieditable.h"
 #include "nact-tree-view.h"
 
@@ -53,7 +53,7 @@ static gchar  *add_ndeletable_msg( const FMAObjectItem *item, gint reason );
 static void    update_clipboard_counters( FMAMainWindow *window, sMenuData *sdata );
 
 /**
- * nact_menu_edit_update_sensitivities:
+ * fma_menu_edit_update_sensitivities:
  * @main_window: the #FMAMainWindow main window.
  *
  * Update sensitivity of items of the Edit menu.
@@ -64,7 +64,7 @@ static void    update_clipboard_counters( FMAMainWindow *window, sMenuData *sdat
  * Menubar rule).
  */
 void
-nact_menu_edit_update_sensitivities( FMAMainWindow *main_window )
+fma_menu_edit_update_sensitivities( FMAMainWindow *main_window )
 {
        sMenuData *sdata;
        gboolean cut_enabled;
@@ -78,7 +78,7 @@ nact_menu_edit_update_sensitivities( FMAMainWindow *main_window )
        FMAObject *selected_item;
        gboolean is_clipboard_empty;
 
-       sdata = nact_menu_get_data( main_window );
+       sdata = fma_menu_get_data( main_window );
        is_clipboard_empty = ( sdata->clipboard_menus + sdata->clipboard_actions + sdata->clipboard_profiles 
== 0 );
 
        /* cut requires a non-empty selection
@@ -90,12 +90,12 @@ nact_menu_edit_update_sensitivities( FMAMainWindow *main_window )
        duplicate_enabled &= sdata->are_parents_writable;
        cut_enabled = duplicate_enabled;
        cut_enabled &= sdata->are_items_writable;
-       nact_menu_enable_item( main_window, "cut", cut_enabled );
+       fma_menu_enable_item( main_window, "cut", cut_enabled );
 
        /* copy only requires a non-empty selection */
        copy_enabled = sdata->treeview_has_focus || sdata->popup_handler;
        copy_enabled &= sdata->count_selected > 0;
-       nact_menu_enable_item( main_window, "copy", copy_enabled );
+       fma_menu_enable_item( main_window, "copy", copy_enabled );
 
        /* paste enabled if
         * - clipboard is not empty
@@ -121,7 +121,7 @@ nact_menu_edit_update_sensitivities( FMAMainWindow *main_window )
                        paste_enabled &= sdata->is_level_zero_writable;
                }
        }
-       nact_menu_enable_item( main_window, "paste", paste_enabled );
+       fma_menu_enable_item( main_window, "paste", paste_enabled );
 
        /* paste into enabled if
         * - clipboard is not empty
@@ -160,26 +160,26 @@ nact_menu_edit_update_sensitivities( FMAMainWindow *main_window )
                        paste_into_enabled &= sdata->is_level_zero_writable;
                }
        }
-       nact_menu_enable_item( main_window, "paste-into", paste_into_enabled );
+       fma_menu_enable_item( main_window, "paste-into", paste_into_enabled );
 
        /* duplicate items will be duplicated besides each one
         * selection must be non-empty
         * each parent must be writable
         */
-       nact_menu_enable_item( main_window, "duplicate", duplicate_enabled );
+       fma_menu_enable_item( main_window, "duplicate", duplicate_enabled );
 
        /* delete is same that cut
         * but items themselves must be writable (because physically deleted)
         * this will be checked on delete activated
         */
        delete_enabled = cut_enabled;
-       nact_menu_enable_item( main_window, "delete", delete_enabled );
+       fma_menu_enable_item( main_window, "delete", delete_enabled );
 
        /* reload items always enabled */
 }
 
 /**
- * nact_menu_edit_cut:
+ * fma_menu_edit_cut:
  * @main_window: the #FMAMainWindow main window.
  *
  * Cut objects are installed both in the clipboard and in the deleted list.
@@ -199,9 +199,9 @@ nact_menu_edit_update_sensitivities( FMAMainWindow *main_window )
  * - (tree) remove selected items, unreffing objects
  */
 void
-nact_menu_edit_cut( FMAMainWindow *main_window )
+fma_menu_edit_cut( FMAMainWindow *main_window )
 {
-       static const gchar *thisfn = "nact_menu_edit_cut";
+       static const gchar *thisfn = "fma_menu_edit_cut";
        sMenuData *sdata;
        GList *items;
        FMAClipboard *clipboard;
@@ -212,7 +212,7 @@ nact_menu_edit_cut( FMAMainWindow *main_window )
        g_debug( "%s: main_window=%p", thisfn, ( void * ) main_window );
        g_return_if_fail( main_window && FMA_IS_MAIN_WINDOW( main_window ));
 
-       sdata = nact_menu_get_data( main_window );
+       sdata = fma_menu_get_data( main_window );
        items = fma_object_copyref_items( sdata->selected_items );
        ndeletables = NULL;
        to_delete = get_deletables( sdata->updater, items, &ndeletables );
@@ -239,7 +239,7 @@ nact_menu_edit_cut( FMAMainWindow *main_window )
 }
 
 /**
- * nact_menu_edit_copy:
+ * fma_menu_edit_copy:
  * @main_window: the #FMAMainWindow main window.
  *
  * copies the visible selection
@@ -250,16 +250,16 @@ nact_menu_edit_cut( FMAMainWindow *main_window )
  * - (menu) refresh actions sensitivy (as selection doesn't change)
  */
 void
-nact_menu_edit_copy( FMAMainWindow *main_window )
+fma_menu_edit_copy( FMAMainWindow *main_window )
 {
-       static const gchar *thisfn = "nact_menu_edit_copy";
+       static const gchar *thisfn = "fma_menu_edit_copy";
        sMenuData *sdata;
        FMAClipboard *clipboard;
 
        g_debug( "%s: main_window=%p", thisfn, ( void * ) main_window );
        g_return_if_fail( main_window && FMA_IS_MAIN_WINDOW( main_window ));
 
-       sdata = nact_menu_get_data( main_window );
+       sdata = fma_menu_get_data( main_window );
 
        clipboard = fma_main_window_get_clipboard( main_window );
        fma_clipboard_primary_set( clipboard, sdata->selected_items, CLIPBOARD_MODE_COPY );
@@ -269,7 +269,7 @@ nact_menu_edit_copy( FMAMainWindow *main_window )
 }
 
 /**
- * nact_menu_edit_paste:
+ * fma_menu_edit_paste:
  * @main_window: the #FMAMainWindow main window.
  *
  * pastes the current content of the clipboard at the current position
@@ -284,9 +284,9 @@ nact_menu_edit_copy( FMAMainWindow *main_window )
  * - (menu) unreffing the copy got from clipboard
  */
 void
-nact_menu_edit_paste( FMAMainWindow *main_window )
+fma_menu_edit_paste( FMAMainWindow *main_window )
 {
-       static const gchar *thisfn = "nact_menu_edit_paste";
+       static const gchar *thisfn = "fma_menu_edit_paste";
        sMenuData *sdata;
        GList *items;
        NactTreeView *view;
@@ -294,7 +294,7 @@ nact_menu_edit_paste( FMAMainWindow *main_window )
        g_debug( "%s: main_window=%p", thisfn, ( void * ) main_window );
        g_return_if_fail( main_window && FMA_IS_MAIN_WINDOW( main_window ));
 
-       sdata = nact_menu_get_data( main_window );
+       sdata = fma_menu_get_data( main_window );
        items = prepare_for_paste( main_window, sdata );
 
        if( items ){
@@ -305,7 +305,7 @@ nact_menu_edit_paste( FMAMainWindow *main_window )
 }
 
 /**
- * nact_menu_edit_paste_into:
+ * fma_menu_edit_paste_into:
  * @main_window: the #FMAMainWindow main window.
  *
  * pastes the current content of the clipboard as the first child of
@@ -320,9 +320,9 @@ nact_menu_edit_paste( FMAMainWindow *main_window )
  * - (menu) unreffing the copy got from clipboard
  */
 void
-nact_menu_edit_paste_into( FMAMainWindow *main_window )
+fma_menu_edit_paste_into( FMAMainWindow *main_window )
 {
-       static const gchar *thisfn = "nact_menu_edit_paste_into";
+       static const gchar *thisfn = "fma_menu_edit_paste_into";
        sMenuData *sdata;
        GList *items;
        NactTreeView *view;
@@ -330,7 +330,7 @@ nact_menu_edit_paste_into( FMAMainWindow *main_window )
        g_debug( "%s: main_window=%p", thisfn, ( void * ) main_window );
        g_return_if_fail( main_window && FMA_IS_MAIN_WINDOW( main_window ));
 
-       sdata = nact_menu_get_data( main_window );
+       sdata = fma_menu_get_data( main_window );
        items = prepare_for_paste( main_window, sdata );
 
        if( items ){
@@ -343,7 +343,7 @@ nact_menu_edit_paste_into( FMAMainWindow *main_window )
 static GList *
 prepare_for_paste( FMAMainWindow *window, sMenuData *sdata )
 {
-       static const gchar *thisfn = "nact_menu_edit_prepare_for_paste";
+       static const gchar *thisfn = "fma_menu_edit_prepare_for_paste";
        GList *items, *it;
        FMAClipboard *clipboard;
        FMAObjectAction *action;
@@ -377,7 +377,7 @@ prepare_for_paste( FMAMainWindow *window, sMenuData *sdata )
 }
 
 /**
- * nact_menu_edit_duplicate:
+ * fma_menu_edit_duplicate:
  * @main_window: the #FMAMainWindow main window.
  *
  * duplicate is just as paste, with the difference that content comes
@@ -388,9 +388,9 @@ prepare_for_paste( FMAMainWindow *window, sMenuData *sdata )
  * items just besides the original ones...
  */
 void
-nact_menu_edit_duplicate( FMAMainWindow *main_window )
+fma_menu_edit_duplicate( FMAMainWindow *main_window )
 {
-       static const gchar *thisfn = "nact_menu_edit_duplicate";
+       static const gchar *thisfn = "fma_menu_edit_duplicate";
        sMenuData *sdata;
        FMAObjectAction *action;
        GList *items, *it;
@@ -402,7 +402,7 @@ nact_menu_edit_duplicate( FMAMainWindow *main_window )
        g_debug( "%s: main_window=%p", thisfn, ( void * ) main_window );
        g_return_if_fail( main_window && FMA_IS_MAIN_WINDOW( main_window ));
 
-       sdata = nact_menu_get_data( main_window );
+       sdata = fma_menu_get_data( main_window );
        items = fma_object_copyref_items( sdata->selected_items );
 
        for( it = items ; it ; it = it->next ){
@@ -430,7 +430,7 @@ nact_menu_edit_duplicate( FMAMainWindow *main_window )
 }
 
 /**
- * nact_menu_edit_delete:
+ * fma_menu_edit_delete:
  * @main_window: the #FMAMainWindow main window.
  *
  * deletes the visible selection
@@ -446,9 +446,9 @@ nact_menu_edit_duplicate( FMAMainWindow *main_window )
  * this branch itself be deleted
  */
 void
-nact_menu_edit_delete( FMAMainWindow *main_window )
+fma_menu_edit_delete( FMAMainWindow *main_window )
 {
-       static const gchar *thisfn = "nact_menu_edit_delete";
+       static const gchar *thisfn = "fma_menu_edit_delete";
        sMenuData *sdata;
        GList *items;
        GList *to_delete;
@@ -458,7 +458,7 @@ nact_menu_edit_delete( FMAMainWindow *main_window )
        g_debug( "%s: main_window=%p", thisfn, ( void * ) main_window );
        g_return_if_fail( main_window && FMA_IS_MAIN_WINDOW( main_window ));
 
-       sdata = nact_menu_get_data( main_window );
+       sdata = fma_menu_get_data( main_window );
        items = fma_object_copyref_items( sdata->selected_items );
        ndeletables = NULL;
        to_delete = get_deletables( sdata->updater, items, &ndeletables );
@@ -577,7 +577,7 @@ update_clipboard_counters( FMAMainWindow *main_window, sMenuData *sdata )
        sdata->clipboard_actions = sdata->selected_actions;
        sdata->clipboard_profiles = sdata->selected_profiles;
 
-       g_debug( "nact_menu_update_clipboard_counters: menus=%d, actions=%d, profiles=%d",
+       g_debug( "fma_menu_update_clipboard_counters: menus=%d, actions=%d, profiles=%d",
                        sdata->clipboard_menus, sdata->clipboard_actions, sdata->clipboard_profiles );
 
        g_signal_emit_by_name( main_window, MAIN_SIGNAL_UPDATE_SENSITIVITIES );
diff --git a/src/ui/nact-menu-edit.h b/src/ui/fma-menu-edit.h
similarity index 66%
rename from src/ui/nact-menu-edit.h
rename to src/ui/fma-menu-edit.h
index 244a69e..8fee599 100644
--- a/src/ui/nact-menu-edit.h
+++ b/src/ui/fma-menu-edit.h
@@ -27,27 +27,27 @@
  *   ... and many others (see AUTHORS)
  */
 
-#ifndef __UI_NACT_MENU_EDIT_H__
-#define __UI_NACT_MENU_EDIT_H__
+#ifndef __UI_FMA_MENU_EDIT_H__
+#define __UI_FMA_MENU_EDIT_H__
 
 #include "fma-main-window-def.h"
 
 G_BEGIN_DECLS
 
-void nact_menu_edit_update_sensitivities( FMAMainWindow *main_window );
+void fma_menu_edit_update_sensitivities( FMAMainWindow *main_window );
 
-void nact_menu_edit_cut                 ( FMAMainWindow *main_window );
+void fma_menu_edit_cut                 ( FMAMainWindow *main_window );
 
-void nact_menu_edit_copy                ( FMAMainWindow *main_window );
+void fma_menu_edit_copy                ( FMAMainWindow *main_window );
 
-void nact_menu_edit_paste               ( FMAMainWindow *main_window );
+void fma_menu_edit_paste               ( FMAMainWindow *main_window );
 
-void nact_menu_edit_paste_into          ( FMAMainWindow *main_window );
+void fma_menu_edit_paste_into          ( FMAMainWindow *main_window );
 
-void nact_menu_edit_duplicate           ( FMAMainWindow *main_window );
+void fma_menu_edit_duplicate           ( FMAMainWindow *main_window );
 
-void nact_menu_edit_delete              ( FMAMainWindow *main_window );
+void fma_menu_edit_delete              ( FMAMainWindow *main_window );
 
 G_END_DECLS
 
-#endif /* __UI_NACT_MENU_EDIT_H__ */
+#endif /* __UI_FMA_MENU_EDIT_H__ */
diff --git a/src/ui/nact-menu-file.h b/src/ui/fma-menu-file.h
similarity index 69%
rename from src/ui/nact-menu-file.h
rename to src/ui/fma-menu-file.h
index 4cc459a..23f9bf2 100644
--- a/src/ui/nact-menu-file.h
+++ b/src/ui/fma-menu-file.h
@@ -27,25 +27,25 @@
  *   ... and many others (see AUTHORS)
  */
 
-#ifndef __UI_NACT_MENU_FILE_H__
-#define __UI_NACT_MENU_FILE_H__
+#ifndef __UI_FMA_MENU_FILE_H__
+#define __UI_FMA_MENU_FILE_H__
 
 #include "fma-main-window-def.h"
 
 G_BEGIN_DECLS
 
-void nact_menu_file_init                ( FMAMainWindow *main_window );
+void fma_menu_file_init                ( FMAMainWindow *main_window );
 
-void nact_menu_file_update_sensitivities( FMAMainWindow *main_window );
+void fma_menu_file_update_sensitivities( FMAMainWindow *main_window );
 
-void nact_menu_file_new_menu            ( FMAMainWindow *main_window );
+void fma_menu_file_new_menu            ( FMAMainWindow *main_window );
 
-void nact_menu_file_new_action          ( FMAMainWindow *main_window );
+void fma_menu_file_new_action          ( FMAMainWindow *main_window );
 
-void nact_menu_file_new_profile         ( FMAMainWindow *main_window );
+void fma_menu_file_new_profile         ( FMAMainWindow *main_window );
 
-void nact_menu_file_save_items          ( FMAMainWindow *main_window );
+void fma_menu_file_save_items          ( FMAMainWindow *main_window );
 
 G_END_DECLS
 
-#endif /* __UI_NACT_MENU_FILE_H__ */
+#endif /* __UI_FMA_MENU_FILE_H__ */
diff --git a/src/ui/nact-menu-view.c b/src/ui/fma-menu-view.c
similarity index 90%
rename from src/ui/nact-menu-view.c
rename to src/ui/fma-menu-view.c
index 25ec44d..4f6ba0c 100644
--- a/src/ui/nact-menu-view.c
+++ b/src/ui/fma-menu-view.c
@@ -35,8 +35,8 @@
 #include "core/fma-iprefs.h"
 
 #include "fma-main-window.h"
-#include "nact-menu.h"
-#include "nact-menu-view.h"
+#include "fma-menu.h"
+#include "fma-menu-view.h"
 
 /* defines the toolbar properties
  */
@@ -87,36 +87,36 @@ static sNotebookTabsProps *get_notebook_tabs_properties_by_pos( guint pos );
 void                       set_notebook_tabs_position( FMAMainWindow *main_window, guint pos );
 
 /**
- * nact_menu_view_init:
+ * fma_menu_view_init:
  * @window: the #FMAMainWindow main window.
  *
  * Setup the toolbars menu at creation time.
  */
 void
-nact_menu_view_init( FMAMainWindow *window )
+fma_menu_view_init( FMAMainWindow *window )
 {
        setup_toolbars_submenu( window );
        setup_notebook_tab_position_submenu( window );
 }
 
 /**
- * nact_menu_view_update_sensitivities:
+ * fma_menu_view_update_sensitivities:
  * @window: the #FMAMainWindow main window.
  *
  * Update sensitivity of items of the View menu.
  */
 void
-nact_menu_view_update_sensitivities( FMAMainWindow *window )
+fma_menu_view_update_sensitivities( FMAMainWindow *window )
 {
        sMenuData *sdata;
        guint count_list;
 
-       sdata = nact_menu_get_data( window );
+       sdata = fma_menu_get_data( window );
 
        /* expand all/collapse all requires at least one item in the list */
        count_list = sdata->count_menus + sdata->count_actions + sdata->count_profiles;
-       nact_menu_enable_item( window, "expand", count_list > 0 );
-       nact_menu_enable_item( window, "collapse", count_list > 0 );
+       fma_menu_enable_item( window, "expand", count_list > 0 );
+       fma_menu_enable_item( window, "collapse", count_list > 0 );
 }
 
 /*
@@ -167,7 +167,7 @@ setup_toolbar( FMAMainWindow *window, GtkBuilder *builder, guint toolbar_id )
 static sToolbarProps *
 get_toolbar_properties_by_id( guint toolbar_id )
 {
-       static const gchar *thisfn = "nact_menu_view_get_toolbar_properties_by_id";
+       static const gchar *thisfn = "fma_menu_view_get_toolbar_properties_by_id";
        guint i;
 
        for( i=0 ; i < G_N_ELEMENTS( st_toolbar_props ) ; ++i ){
@@ -181,13 +181,13 @@ get_toolbar_properties_by_id( guint toolbar_id )
 }
 
 /**
- * nact_menu_view_toolbar_display:
+ * fma_menu_view_toolbar_display:
  * @main_window: the #FMAMainWindow main window.
  * @action_name: the action name.
  * @visible: whether the toolbar must be displayed or hidden.
  */
 void
-nact_menu_view_toolbar_display( FMAMainWindow *main_window, const gchar *action_name, gboolean visible )
+fma_menu_view_toolbar_display( FMAMainWindow *main_window, const gchar *action_name, gboolean visible )
 {
        sToolbarProps *props;
        GtkWidget *parent;
@@ -212,7 +212,7 @@ nact_menu_view_toolbar_display( FMAMainWindow *main_window, const gchar *action_
 static sToolbarProps *
 get_toolbar_properties_by_name( const gchar *action_name )
 {
-       static const gchar *thisfn = "nact_menu_view_get_toolbar_properties_by_name";
+       static const gchar *thisfn = "fma_menu_view_get_toolbar_properties_by_name";
        guint i;
 
        for( i=0 ; i < G_N_ELEMENTS( st_toolbar_props ) ; ++i ){
@@ -303,7 +303,7 @@ setup_notebook_tab_position_submenu( FMAMainWindow *window )
  * GtkRadioButtons items share the same "current_value".
  */
 void
-nact_menu_view_on_tabs_pos_changed( GtkRadioAction *action, GtkRadioAction *current, BaseWindow *window )
+fma_menu_view_on_tabs_pos_changed( GtkRadioAction *action, GtkRadioAction *current, BaseWindow *window )
 {
        GtkNotebook *notebook;
        guint new_pos;
@@ -315,13 +315,13 @@ nact_menu_view_on_tabs_pos_changed( GtkRadioAction *action, GtkRadioAction *curr
 #endif
 
 /**
- * nact_menu_view_notebook_tab_display:
+ * fma_menu_view_notebook_tab_display:
  * @main_window: the #FMAMainWindow main window.
  * @action_name: the action name.
  * @target: the targeted position.
  */
 void
-nact_menu_view_notebook_tab_display( FMAMainWindow *main_window, const gchar *action_name, const gchar 
*target )
+fma_menu_view_notebook_tab_display( FMAMainWindow *main_window, const gchar *action_name, const gchar 
*target )
 {
        sNotebookTabsProps *props;
 
@@ -337,7 +337,7 @@ nact_menu_view_notebook_tab_display( FMAMainWindow *main_window, const gchar *ac
 static sNotebookTabsProps *
 get_notebook_tabs_properties_by_target( const gchar *target )
 {
-       static const gchar *thisfn = "nact_menu_view_get_notebook_tabs_properties_by_target";
+       static const gchar *thisfn = "fma_menu_view_get_notebook_tabs_properties_by_target";
        guint i;
 
        for( i=0 ; i<G_N_ELEMENTS( st_notebook_tabs_props ) ; ++i ){
@@ -356,7 +356,7 @@ get_notebook_tabs_properties_by_target( const gchar *target )
 static sNotebookTabsProps *
 get_notebook_tabs_properties_by_pos( guint pos )
 {
-       static const gchar *thisfn = "nact_menu_view_get_notebook_tabs_properties_by_pos";
+       static const gchar *thisfn = "fma_menu_view_get_notebook_tabs_properties_by_pos";
        guint i;
 
        for( i=0 ; i<G_N_ELEMENTS( st_notebook_tabs_props ) ; ++i ){
diff --git a/src/ui/nact-menu-view.h b/src/ui/fma-menu-view.h
similarity index 76%
rename from src/ui/nact-menu-view.h
rename to src/ui/fma-menu-view.h
index 7cb6059..696d99d 100644
--- a/src/ui/nact-menu-view.h
+++ b/src/ui/fma-menu-view.h
@@ -27,8 +27,8 @@
  *   ... and many others (see AUTHORS)
  */
 
-#ifndef __UI_NACT_MENU_VIEW_H__
-#define __UI_NACT_MENU_VIEW_H__
+#ifndef __UI_FMA_MENU_VIEW_H__
+#define __UI_FMA_MENU_VIEW_H__
 
 #include "fma-main-window-def.h"
 
@@ -41,20 +41,20 @@ enum {
        MAIN_TOOLBAR_HELP_ID,
 };
 
-void nact_menu_view_init                ( FMAMainWindow *main_window );
+void fma_menu_view_init                ( FMAMainWindow *main_window );
 
-void nact_menu_view_update_sensitivities( FMAMainWindow *main_window );
+void fma_menu_view_update_sensitivities( FMAMainWindow *main_window );
 
-void nact_menu_view_toolbar_display     ( FMAMainWindow *main_window,
+void fma_menu_view_toolbar_display     ( FMAMainWindow *main_window,
                                                                                                const gchar 
*action_name,
                                                                                                gboolean 
visible );
 
-void nact_menu_view_notebook_tab_display( FMAMainWindow *main_window,
+void fma_menu_view_notebook_tab_display( FMAMainWindow *main_window,
                                                                                                const gchar 
*action_name,
                                                                                                const gchar 
*target );
 
-void nact_menu_view_set_notebook_label  ( FMAMainWindow *main_window );
+void fma_menu_view_set_notebook_label  ( FMAMainWindow *main_window );
 
 G_END_DECLS
 
-#endif /* __UI_NACT_MENU_VIEW_H__ */
+#endif /* __UI_FMA_MENU_VIEW_H__ */
diff --git a/src/ui/nact-menu.c b/src/ui/fma-menu.c
similarity index 92%
rename from src/ui/nact-menu.c
rename to src/ui/fma-menu.c
index cf5a48e..59f6b01 100644
--- a/src/ui/nact-menu.c
+++ b/src/ui/fma-menu.c
@@ -37,18 +37,18 @@
 #include "core/fma-io-provider.h"
 
 #include "fma-main-window.h"
-#include "nact-menu.h"
-#include "nact-menu-edit.h"
-#include "nact-menu-file.h"
-#include "nact-menu-view.h"
+#include "fma-menu.h"
+#include "fma-menu-edit.h"
+#include "fma-menu-file.h"
+#include "fma-menu-view.h"
 /*
-#include "nact-menu-maintainer.h"
-#include "nact-menu-tools.h"
+#include "fma-menu-maintainer.h"
+#include "fma-menu-tools.h"
 */
 #include "nact-preferences-editor.h"
 #include "nact-tree-view.h"
 
-static const gchar *st_uixml_actions    = PKGUIDIR "/filemanager-actions-config-tool.actions";
+static const gchar *st_uixml_actions    = PKGUIDIR "/fma-ui.actions";
 static const gchar *st_ui_app_menu      = "app-menu";
 static const gchar *st_ui_menubar       = "menubar";
 
@@ -176,7 +176,7 @@ static sActionEntry st_menubar_entries[] = {
                {{ "dump-clipboard", on_win_dump_clipboard },
                                "Dump the content of the clipboard object" },
                {{ "fntest", on_win_test_function },
-                               "Test a function (see nact-menubar-maintainer.c" },
+                               "Test a function (see fma-menubar-maintainer.c" },
 };
 
 static void       free_menu_data( sMenuData *sdata );
@@ -190,7 +190,7 @@ static void       on_tree_view_selection_changed( NactTreeView *treeview, GList
 static void       on_update_sensitivities( FMAMainWindow *window, void *empty );
 
 /**
- * nact_menu_app:
+ * fma_menu_app:
  * @application: the #FMAApplication.
  *
  * Define the application menu and attach it to the application.
@@ -200,9 +200,9 @@ static void       on_update_sensitivities( FMAMainWindow *window, void *empty );
  * Quit, etc.)
  */
 void
-nact_menu_app( FMAApplication *application )
+fma_menu_app( FMAApplication *application )
 {
-       static const gchar *thisfn = "nact_menu_app";
+       static const gchar *thisfn = "fma_menu_app";
        GError *error;
        GtkBuilder *builder;
        GMenuModel *appmenu, *menubar;
@@ -257,7 +257,7 @@ on_app_about( GSimpleAction *action, GVariant *parameter, gpointer user_data )
 static void
 on_app_help( GSimpleAction *action, GVariant *parameter, gpointer user_data )
 {
-       static const gchar *thisfn = "nact_menu_on_app_help";
+       static const gchar *thisfn = "fma_menu_on_app_help";
        GError *error;
 
        g_return_if_fail( user_data && FMA_IS_APPLICATION( user_data ));
@@ -297,21 +297,21 @@ on_app_quit( GSimpleAction *action, GVariant *parameter, gpointer user_data )
 }
 
 /**
- * nact_menu_win:
+ * fma_menu_win:
  * @main_window: the #FMAMainWindow.
  *
  * Define the window menubar and attach it to the main window.
  */
 void
-nact_menu_win( FMAMainWindow *main_window )
+fma_menu_win( FMAMainWindow *main_window )
 {
-       static const gchar *thisfn = "nact_menu_win";
+       static const gchar *thisfn = "fma_menu_win";
        gint i;
        GtkApplication *application;
        NactTreeView *treeview;
        sMenuData *sdata;
 
-       sdata = nact_menu_get_data( main_window );
+       sdata = fma_menu_get_data( main_window );
 
        for( i=0 ; i<G_N_ELEMENTS( st_menubar_entries ) ; ++i ){
                g_action_map_add_action_entries(
@@ -367,19 +367,19 @@ nact_menu_win( FMAMainWindow *main_window )
                                        G_CALLBACK( on_update_sensitivities ), NULL );
 
        /* install autosave */
-       nact_menu_file_init( main_window );
+       fma_menu_file_init( main_window );
 
        /* install toolbar submenu
         * + notebook labels position submenu */
-       nact_menu_view_init( main_window );
+       fma_menu_view_init( main_window );
 }
 
 /**
- * nact_menu_get_data:
+ * fma_menu_get_data:
  * @main_window: the #FMAMainWindow main window.
  */
 sMenuData *
-nact_menu_get_data( FMAMainWindow *main_window )
+fma_menu_get_data( FMAMainWindow *main_window )
 {
        sMenuData *sdata;
 
@@ -406,7 +406,7 @@ on_open_context_menu( NactTreeView *treeview, GdkEventButton *event, FMAMainWind
 {
        sMenuData *sdata;
 
-       sdata = nact_menu_get_data( window );
+       sdata = fma_menu_get_data( window );
 
        sdata->popup_handler = g_signal_connect(
                        sdata->popup, "selection-done", G_CALLBACK( on_popup_selection_done ), window );
@@ -423,12 +423,12 @@ on_open_context_menu( NactTreeView *treeview, GdkEventButton *event, FMAMainWind
 static void
 on_popup_selection_done( GtkMenuShell *menushell, FMAMainWindow *window )
 {
-       static const gchar *thisfn = "nact_menu_on_popup_selection_done";
+       static const gchar *thisfn = "fma_menu_on_popup_selection_done";
        sMenuData *sdata;
 
        g_debug( "%s", thisfn );
 
-       sdata = nact_menu_get_data( window );
+       sdata = fma_menu_get_data( window );
        g_signal_handler_disconnect( menushell, sdata->popup_handler );
        sdata->popup_handler = ( gulong ) 0;
 }
@@ -440,7 +440,7 @@ on_popup_selection_done( GtkMenuShell *menushell, FMAMainWindow *window )
 static void
 on_tree_view_count_changed( NactTreeView *treeview, gboolean reset, gint menus, gint actions, gint profiles, 
FMAMainWindow *window )
 {
-       static const gchar *thisfn = "nact_menu_on_tree_view_count_changed";
+       static const gchar *thisfn = "fma_menu_on_tree_view_count_changed";
        sMenuData *sdata;
        NactStatusbar *bar;
        gchar *status;
@@ -449,7 +449,7 @@ on_tree_view_count_changed( NactTreeView *treeview, gboolean reset, gint menus,
                        thisfn, ( void * ) treeview,
                        reset ? "True":"False", menus, actions, profiles, ( void * ) window );
 
-       sdata = nact_menu_get_data( window );
+       sdata = fma_menu_get_data( window );
 
        if( reset ){
                sdata->count_menus = menus;
@@ -481,7 +481,7 @@ on_tree_view_focus_in( NactTreeView *treeview, FMAMainWindow *window )
 {
        sMenuData *sdata;
 
-       sdata = nact_menu_get_data( window );
+       sdata = fma_menu_get_data( window );
 
        sdata->treeview_has_focus = TRUE;
        g_signal_emit_by_name( window, MAIN_SIGNAL_UPDATE_SENSITIVITIES );
@@ -492,7 +492,7 @@ on_tree_view_focus_out( NactTreeView *treeview, FMAMainWindow *window )
 {
        sMenuData *sdata;
 
-       sdata = nact_menu_get_data( window );
+       sdata = fma_menu_get_data( window );
 
        sdata->treeview_has_focus = FALSE;
        g_signal_emit_by_name( window, MAIN_SIGNAL_UPDATE_SENSITIVITIES );
@@ -504,13 +504,13 @@ on_tree_view_focus_out( NactTreeView *treeview, FMAMainWindow *window )
 static void
 on_tree_view_modified_status_changed( NactTreeView *treeview, gboolean is_modified, FMAMainWindow *window )
 {
-       static const gchar *thisfn = "nact_menu_on_tree_view_modified_status_changed";
+       static const gchar *thisfn = "fma_menu_on_tree_view_modified_status_changed";
        sMenuData *sdata;
 
        g_debug( "%s: treeview=%p, is_modified=%s, window=%p",
                        thisfn, ( void * ) treeview, is_modified ? "True":"False", ( void * ) window );
 
-       sdata = nact_menu_get_data( window );
+       sdata = fma_menu_get_data( window );
 
        sdata->is_tree_modified = is_modified;
        g_signal_emit_by_name( window, MAIN_SIGNAL_UPDATE_SENSITIVITIES );
@@ -531,7 +531,7 @@ on_tree_view_modified_status_changed( NactTreeView *treeview, gboolean is_modifi
 static void
 on_tree_view_selection_changed( NactTreeView *treeview, GList *selected, FMAMainWindow *window )
 {
-       static const gchar *thisfn = "nact_menu_on_tree_view_selection_changed";
+       static const gchar *thisfn = "fma_menu_on_tree_view_selection_changed";
        sMenuData *sdata;
        FMAObject *first;
        FMAObject *selected_action;
@@ -542,7 +542,7 @@ on_tree_view_selection_changed( NactTreeView *treeview, GList *selected, FMAMain
                        thisfn, ( void * ) treeview,
                        ( void * ) selected, g_list_length( selected ), ( void * ) window );
 
-       sdata = nact_menu_get_data( window );
+       sdata = fma_menu_get_data( window );
 
        /* count the items
         */
@@ -653,18 +653,18 @@ on_tree_view_selection_changed( NactTreeView *treeview, GList *selected, FMAMain
 static void
 on_update_sensitivities( FMAMainWindow *window, void *empty )
 {
-       static const gchar *thisfn = "nact_menu_on_update_sensitivities";
+       static const gchar *thisfn = "fma_menu_on_update_sensitivities";
 
        g_debug( "%s: window=%p, empty=%p", thisfn, ( void * ) window, empty );
 
        if( !fma_main_window_dispose_has_run( window )){
 
-               nact_menu_file_update_sensitivities( window );
-               nact_menu_edit_update_sensitivities( window );
-               nact_menu_view_update_sensitivities( window );
-               /*nact_menu_tools_update_sensitivities( window );
-               nact_menu_maintainer_update_sensitivities( window );
-               nact_menu_help_update_sensitivities( window );*/
+               fma_menu_file_update_sensitivities( window );
+               fma_menu_edit_update_sensitivities( window );
+               fma_menu_view_update_sensitivities( window );
+               /*fma_menu_tools_update_sensitivities( window );
+               fma_menu_maintainer_update_sensitivities( window );
+               fma_menu_help_update_sensitivities( window );*/
        }
 }
 
@@ -689,21 +689,21 @@ static void
 on_win_copy( GSimpleAction *action, GVariant *parameter, gpointer user_data )
 {
        g_return_if_fail( user_data && FMA_IS_MAIN_WINDOW( user_data ));
-       nact_menu_edit_copy( FMA_MAIN_WINDOW( user_data ));
+       fma_menu_edit_copy( FMA_MAIN_WINDOW( user_data ));
 }
 
 static void
 on_win_cut( GSimpleAction *action, GVariant *parameter, gpointer user_data )
 {
        g_return_if_fail( user_data && FMA_IS_MAIN_WINDOW( user_data ));
-       nact_menu_edit_cut( FMA_MAIN_WINDOW( user_data ));
+       fma_menu_edit_cut( FMA_MAIN_WINDOW( user_data ));
 }
 
 static void
 on_win_delete( GSimpleAction *action, GVariant *parameter, gpointer user_data )
 {
        g_return_if_fail( user_data && FMA_IS_MAIN_WINDOW( user_data ));
-       nact_menu_edit_delete( FMA_MAIN_WINDOW( user_data ));
+       fma_menu_edit_delete( FMA_MAIN_WINDOW( user_data ));
 }
 
 static void
@@ -722,7 +722,7 @@ static void
 on_win_duplicate( GSimpleAction *action, GVariant *parameter, gpointer user_data )
 {
        g_return_if_fail( user_data && FMA_IS_MAIN_WINDOW( user_data ));
-       nact_menu_edit_duplicate( FMA_MAIN_WINDOW( user_data ));
+       fma_menu_edit_duplicate( FMA_MAIN_WINDOW( user_data ));
 }
 
 static void
@@ -758,35 +758,35 @@ static void
 on_win_new_action( GSimpleAction *action, GVariant *parameter, gpointer user_data )
 {
        g_return_if_fail( user_data && FMA_IS_MAIN_WINDOW( user_data ));
-       nact_menu_file_new_action( FMA_MAIN_WINDOW( user_data ));
+       fma_menu_file_new_action( FMA_MAIN_WINDOW( user_data ));
 }
 
 static void
 on_win_new_menu( GSimpleAction *action, GVariant *parameter, gpointer user_data )
 {
        g_return_if_fail( user_data && FMA_IS_MAIN_WINDOW( user_data ));
-       nact_menu_file_new_menu( FMA_MAIN_WINDOW( user_data ));
+       fma_menu_file_new_menu( FMA_MAIN_WINDOW( user_data ));
 }
 
 static void
 on_win_new_profile( GSimpleAction *action, GVariant *parameter, gpointer user_data )
 {
        g_return_if_fail( user_data && FMA_IS_MAIN_WINDOW( user_data ));
-       nact_menu_file_new_profile( FMA_MAIN_WINDOW( user_data ));
+       fma_menu_file_new_profile( FMA_MAIN_WINDOW( user_data ));
 }
 
 static void
 on_win_paste( GSimpleAction *action, GVariant *parameter, gpointer user_data )
 {
        g_return_if_fail( user_data && FMA_IS_MAIN_WINDOW( user_data ));
-       nact_menu_edit_paste( FMA_MAIN_WINDOW( user_data ));
+       fma_menu_edit_paste( FMA_MAIN_WINDOW( user_data ));
 }
 
 static void
 on_win_paste_into( GSimpleAction *action, GVariant *parameter, gpointer user_data )
 {
        g_return_if_fail( user_data && FMA_IS_MAIN_WINDOW( user_data ));
-       nact_menu_edit_paste_into( FMA_MAIN_WINDOW( user_data ));
+       fma_menu_edit_paste_into( FMA_MAIN_WINDOW( user_data ));
 }
 
 static void
@@ -800,7 +800,7 @@ static void
 on_win_save( GSimpleAction *action, GVariant *parameter, gpointer user_data )
 {
        g_return_if_fail( user_data && FMA_IS_MAIN_WINDOW( user_data ));
-       nact_menu_file_save_items( FMA_MAIN_WINDOW( user_data ));
+       fma_menu_file_save_items( FMA_MAIN_WINDOW( user_data ));
 }
 
 static void
@@ -835,7 +835,7 @@ on_win_toolbar_changed_state( GSimpleAction *action, GVariant *state, gpointer u
 {
        g_return_if_fail( user_data && FMA_IS_MAIN_WINDOW( user_data ));
 
-       nact_menu_view_toolbar_display(
+       fma_menu_view_toolbar_display(
                        FMA_MAIN_WINDOW( user_data ),
                        g_action_get_name( G_ACTION( action )),
                        g_variant_get_boolean( state ));
@@ -865,7 +865,7 @@ on_win_notebook_tab_position_changed_state( GSimpleAction *action, GVariant *sta
 {
        g_return_if_fail( user_data && FMA_IS_MAIN_WINDOW( user_data ));
 
-       nact_menu_view_notebook_tab_display(
+       fma_menu_view_notebook_tab_display(
                        FMA_MAIN_WINDOW( user_data ),
                        g_action_get_name( G_ACTION( action )),
                        g_variant_get_string( state, NULL ));
@@ -874,7 +874,7 @@ on_win_notebook_tab_position_changed_state( GSimpleAction *action, GVariant *sta
 }
 
 /**
- * nact_menu_enable_item:
+ * fma_menu_enable_item:
  * @main_window: this #FMAMainWindow main window.
  * @name: the name of the item in a menu.
  * @enabled: whether this item should be enabled or not.
@@ -882,7 +882,7 @@ on_win_notebook_tab_position_changed_state( GSimpleAction *action, GVariant *sta
  * Enable/disable an item in an menu.
  */
 void
-nact_menu_enable_item( FMAMainWindow *main_window, const gchar *name, gboolean enabled )
+fma_menu_enable_item( FMAMainWindow *main_window, const gchar *name, gboolean enabled )
 {
        GAction *action;
 
diff --git a/src/ui/nact-menu.h b/src/ui/fma-menu.h
similarity index 60%
rename from src/ui/nact-menu.h
rename to src/ui/fma-menu.h
index 3764f44..93e6341 100644
--- a/src/ui/nact-menu.h
+++ b/src/ui/fma-menu.h
@@ -27,14 +27,14 @@
  *   ... and many others (see AUTHORS)
  */
 
-#ifndef __UI_NACT_MENU_H__
-#define __UI_NACT_MENU_H__
+#ifndef __UI_FMA_MENU_H__
+#define __UI_FMA_MENU_H__
 
 /*
- * SECTION: nact-menu
- * @title: NactMenu
+ * SECTION: fma-menu
+ * @title: FMAMenu
  * @short_description: The menu helpers functions
- * @include: nact-menu.h
+ * @include: ui/fma-menu.h
  */
 
 #include "core/fma-updater.h"
@@ -51,48 +51,48 @@ typedef struct {
 
        /* set at initialization time
         */
-       gulong          update_sensitivities_handler_id;
+       gulong           update_sensitivities_handler_id;
        FMAUpdater  *updater;
-       GMenuModel *maintainer;
-       GMenuModel *popup;
-       gboolean    is_level_zero_writable;
-       gboolean    has_writable_providers;
+       GMenuModel  *maintainer;
+       GMenuModel  *popup;
+       gboolean     is_level_zero_writable;
+       gboolean     has_writable_providers;
 
        /* set when the selection changes
         */
-       guint       count_selected;
-       GList      *selected_items;
-       gboolean    is_parent_writable;         /* new menu/new action/paste menu or action */
-       gboolean    enable_new_profile;         /* new profile/paste a profile */
-       gboolean    is_action_writable;
-       gboolean    are_parents_writable;       /* duplicate */
-       gboolean    are_items_writable;         /* cut/delete */
+       guint        count_selected;
+       GList       *selected_items;
+       gboolean     is_parent_writable;                /* new menu/new action/paste menu or action */
+       gboolean     enable_new_profile;                /* new profile/paste a profile */
+       gboolean     is_action_writable;
+       gboolean     are_parents_writable;      /* duplicate */
+       gboolean     are_items_writable;                /* cut/delete */
 
        /* set when the count of modified or deleted FMAObjectItem changes
         * or when the level zero is changed
         */
-       gboolean    is_tree_modified;
+       gboolean     is_tree_modified;
 
        /* set on focus in/out
         */
-       gboolean    treeview_has_focus;
+       gboolean     treeview_has_focus;
 
        /* opening a contextual popup menu
         */
-       gulong      popup_handler;
+       gulong       popup_handler;
 
        /* set when total count of items changes
         */
-       gint        count_menus;
-       gint        count_actions;
-       gint        count_profiles;
-       gboolean    have_exportables;
-       gint        selected_menus;
-       gint        selected_actions;
-       gint        selected_profiles;
-       gint        clipboard_menus;
-       gint        clipboard_actions;
-       gint        clipboard_profiles;
+       gint         count_menus;
+       gint         count_actions;
+       gint         count_profiles;
+       gboolean     have_exportables;
+       gint         selected_menus;
+       gint         selected_actions;
+       gint         selected_profiles;
+       gint         clipboard_menus;
+       gint         clipboard_actions;
+       gint         clipboard_profiles;
 }
        sMenuData;
 
@@ -106,16 +106,16 @@ enum {
        TOOLBAR_HELP_ID,
 };
 
-void       nact_menu_app        ( FMAApplication *application );
+void       fma_menu_app        ( FMAApplication *application );
 
-void       nact_menu_win        ( FMAMainWindow *main_window );
+void       fma_menu_win        ( FMAMainWindow *main_window );
 
-void       nact_menu_enable_item( FMAMainWindow *main_window,
+void       fma_menu_enable_item( FMAMainWindow *main_window,
                                                                                const gchar *action_name,
                                                                                gboolean enable );
 
-sMenuData *nact_menu_get_data   ( FMAMainWindow *main_window );
+sMenuData *fma_menu_get_data   ( FMAMainWindow *main_window );
 
 G_END_DECLS
 
-#endif /* __UI_NACT_MENU_H__ */
+#endif /* __UI_FMA_MENU_H__ */
diff --git a/src/ui/nact-menu-file.c b/src/ui/fma-menu-file.c
similarity index 89%
rename from src/ui/nact-menu-file.c
rename to src/ui/fma-menu-file.c
index 4d97f1e..69d42ae 100644
--- a/src/ui/nact-menu-file.c
+++ b/src/ui/fma-menu-file.c
@@ -44,8 +44,8 @@
 #include "nact-statusbar.h"
 #include "fma-main-tab.h"
 #include "fma-main-window.h"
-#include "nact-menu.h"
-#include "nact-menu-file.h"
+#include "fma-menu.h"
+#include "fma-menu-file.h"
 #include "nact-tree-ieditable.h"
 
 static FMATimeout st_autosave_prefs_timeout = { 0 };
@@ -64,29 +64,29 @@ static gboolean autosave_callback( FMAMainWindow *main_window );
 static void     autosave_destroyed( FMAMainWindow *main_window );
 
 /*
- * nact_menu_file_init:
+ * fma_menu_file_init:
  * @main_window: the #FMAMainWindow main window.
  */
 void
-nact_menu_file_init( FMAMainWindow *main_window )
+fma_menu_file_init( FMAMainWindow *main_window )
 {
        install_autosave( main_window );
 }
 
 /**
- * nact_menu_file_update_sensitivities:
+ * fma_menu_file_update_sensitivities:
  * @main_window: the #FMAMainWindow main window.
  *
  * Update sensitivity of items of the File menu.
  */
 void
-nact_menu_file_update_sensitivities( FMAMainWindow *main_window )
+fma_menu_file_update_sensitivities( FMAMainWindow *main_window )
 {
-       static const gchar *thisfn = "nact_menu_file_update_sensitivities";
+       static const gchar *thisfn = "fma_menu_file_update_sensitivities";
        sMenuData *sdata;
        gboolean new_item_enabled;
 
-       sdata = nact_menu_get_data( main_window );
+       sdata = fma_menu_get_data( main_window );
 
        /* new menu / new action
         * new item will be inserted just before the beginning of selection
@@ -99,37 +99,37 @@ nact_menu_file_update_sensitivities( FMAMainWindow *main_window )
                        sdata->is_parent_writable ? "True":"False",
                        sdata->has_writable_providers ? "True":"False",
                        new_item_enabled ? "True":"False" );
-       nact_menu_enable_item( main_window, "new-menu", new_item_enabled );
-       nact_menu_enable_item( main_window, "new-action", new_item_enabled );
+       fma_menu_enable_item( main_window, "new-menu", new_item_enabled );
+       fma_menu_enable_item( main_window, "new-action", new_item_enabled );
 
        /* new profile enabled if selection is relative to only one writable action
         * i.e. contains profile(s) of the same action, or only contains one action
         * action must be writable
         */
-       nact_menu_enable_item( main_window, "new-profile",
+       fma_menu_enable_item( main_window, "new-profile",
                        sdata->enable_new_profile && sdata->is_action_writable );
 
        /* save enabled if at least one item has been modified
         * or level-zero has been resorted and is writable
         */
-       nact_menu_enable_item( main_window, "save", ( sdata->is_tree_modified ));
+       fma_menu_enable_item( main_window, "save", ( sdata->is_tree_modified ));
 }
 
 /**
- * nact_menu_file_new_menu:
+ * fma_menu_file_new_menu:
  * @main_window: the #FMAMainWindow main window.
  *
  * Triggers File / New menu item.
  */
 void
-nact_menu_file_new_menu( FMAMainWindow *main_window )
+fma_menu_file_new_menu( FMAMainWindow *main_window )
 {
        sMenuData *sdata;
        FMAObjectMenu *menu;
        NactTreeView *items_view;
        GList *items;
 
-       sdata = nact_menu_get_data( main_window );
+       sdata = fma_menu_get_data( main_window );
        menu = fma_object_menu_new_with_defaults();
        fma_object_check_status( menu );
        fma_updater_check_item_writability_status( sdata->updater, FMA_OBJECT_ITEM( menu ));
@@ -140,20 +140,20 @@ nact_menu_file_new_menu( FMAMainWindow *main_window )
 }
 
 /**
- * nact_menu_file_new_action:
+ * fma_menu_file_new_action:
  * @main_window: the #FMAMainWindow main window.
  *
  * Triggers File / New action item.
  */
 void
-nact_menu_file_new_action( FMAMainWindow *main_window )
+fma_menu_file_new_action( FMAMainWindow *main_window )
 {
        sMenuData *sdata;
        FMAObjectAction *action;
        NactTreeView *items_view;
        GList *items;
 
-       sdata = nact_menu_get_data( main_window );
+       sdata = fma_menu_get_data( main_window );
        action = fma_object_action_new_with_defaults();
        fma_object_check_status( action );
        fma_updater_check_item_writability_status( sdata->updater, FMA_OBJECT_ITEM( action ));
@@ -164,13 +164,13 @@ nact_menu_file_new_action( FMAMainWindow *main_window )
 }
 
 /**
- * nact_menu_file_new_profile:
+ * fma_menu_file_new_profile:
  * @main_window: the #FMAMainWindow main window.
  *
  * Triggers File / New profile item.
  */
 void
-nact_menu_file_new_profile( FMAMainWindow *main_window )
+fma_menu_file_new_profile( FMAMainWindow *main_window )
 {
        FMAObjectAction *action;
        FMAObjectProfile *profile;
@@ -197,11 +197,11 @@ nact_menu_file_new_profile( FMAMainWindow *main_window )
 }
 
 /**
- * nact_menu_file_save_items:
+ * fma_menu_file_save_items:
  * @window: the #FMAMainWindow main window.
  *
  * Save items.
  * This is the same function that nact_menu_file_save(), just
  * with different arguments.
  *
  * Synopsis:
@@ -226,9 +226,9 @@ nact_menu_file_new_profile( FMAMainWindow *main_window )
  * - idem if some items cannot be actually rewritten...
  */
 void
-nact_menu_file_save_items( FMAMainWindow *window )
+fma_menu_file_save_items( FMAMainWindow *window )
 {
-       static const gchar *thisfn = "nact_menu_file_save_items";
+       static const gchar *thisfn = "fma_menu_file_save_items";
        sMenuData *sdata;
        NactTreeView *items_view;
        GList *items, *it;
@@ -239,7 +239,7 @@ nact_menu_file_save_items( FMAMainWindow *window )
 
        g_debug( "%s: window=%p", thisfn, ( void * ) window );
 
-       sdata = nact_menu_get_data( window );
+       sdata = fma_menu_get_data( window );
 
        /* always write the level zero list of items as the first save phase
         * and reset the corresponding modification flag
@@ -321,7 +321,7 @@ nact_menu_file_save_items( FMAMainWindow *window )
 static gboolean
 save_item( FMAMainWindow *window, FMAUpdater *updater, FMAObjectItem *item, GSList **messages )
 {
-       static const gchar *thisfn = "nact_menu_file_save_item";
+       static const gchar *thisfn = "fma_menu_file_save_item";
        gboolean ret;
        FMAIOProvider *provider_before;
        FMAIOProvider *provider_after;
@@ -371,7 +371,7 @@ save_item( FMAMainWindow *window, FMAUpdater *updater, FMAObjectItem *item, GSLi
 }
 
 /*
- * nact_menu_file_install_autosave:
+ * fma_menu_file_install_autosave:
  * @main_window: this #FMAMainWindow main window.
  *
  * Setup the autosave feature and initialize its monitoring.
@@ -398,7 +398,7 @@ on_autosave_prefs_changed( const gchar *group, const gchar *key, gconstpointer n
 static void
 on_autosave_prefs_timeout( FMAMainWindow *main_window )
 {
-       static const gchar *thisfn = "nact_menu_file_autosave_prefs_timeout";
+       static const gchar *thisfn = "fma_menu_file_autosave_prefs_timeout";
        gboolean autosave_on;
        guint autosave_period;
 
@@ -427,11 +427,11 @@ autosave_callback( FMAMainWindow *main_window )
 {
        NactStatusbar *bar;
        const gchar *context = "autosave-context";
-       g_debug( "nact_menu_file_autosave_callback" );
+       g_debug( "fma_menu_file_autosave_callback" );
 
        bar = fma_main_window_get_statusbar( main_window );
        nact_statusbar_display_status( bar, context, _( "Automatically saving pending modifications..." ));
-       nact_menu_file_save_items( main_window );
+       fma_menu_file_save_items( main_window );
        nact_statusbar_hide_status( bar, context );
 
        return( TRUE );
@@ -440,5 +440,5 @@ autosave_callback( FMAMainWindow *main_window )
 static void
 autosave_destroyed( FMAMainWindow *main_window )
 {
-       g_debug( "nact_menu_file_autosave_destroyed" );
+       g_debug( "fma_menu_file_autosave_destroyed" );
 }
@@ -197,11 +197,11 @@ nact_menu_file_new_profile( FMAMainWindow *main_window )
  *
  * Save items.
- * This is the same function that nact_menu_file_save(), just
+ * This is the same function that fma_menu_file_save(), just
  * with different arguments.
  *
diff --git a/src/ui/nautilus-actions-config-tool.actions b/src/ui/fma-ui.actions
similarity index 100%
rename from src/ui/nautilus-actions-config-tool.actions
rename to src/ui/fma-ui.actions


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]